#include <stdio.h>
#include <unistd.h>
#include <errno.h>

#define BUFFSZ 256

#ifndef HAVE_BZERO
#define bzero(ptr,n)        memset (ptr, 0, n)
#endif

void error_quit(const char* msg, FILE* pf);

/* Write "n" bytes to a descriptor. */
ssize_t writen(int fd, const void *vptr, size_t n);

void error_quit(const char* msg, FILE* pf)
{
		printf("pid=%d: ", getpid());
		fputs(msg, pf);
		exit (-1);
}

ssize_t writen(int fd, const void *vptr, size_t n)
{
	size_t nleft;
	ssize_t nwritten;
	const char *ptr;

	ptr = vptr;
	nleft = n;
	while (nleft > 0) {
		if ( (nwritten = write(fd, ptr, nleft)) <= 0) {
			if (nwritten < 0 && errno == EINTR)
			nwritten = 0;   /* and call write() again */
		else
			return (-1);    /* error */
		}

		nleft -= nwritten;
		ptr += nwritten;
	}
	return (n);
}

