#include <sys/socket.h>
#include <netinet/in.h>
#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>
#include "comm.h"

/* This srv program listens on port 12000. When a client connects to it, a connection shall be established
 between the client and a new forked srv process. The orignal srv process will continue listening for new
 client connections. Of course, there is a max limit on the total amount of connections depending on your system environment.

 The srv processes do not read data from the sockets, so as to make socket buffer full.
 */
int main(int argc, char **argv)
{
	int listenfd, connfd;
	int n = 0;	/* child counts */
	int cid;	
	char    buff[BUFFSZ];
	struct sockaddr_in servaddr;
	
	listenfd = socket(AF_INET, SOCK_STREAM, 0);
	if(-1 == listenfd) {
		error_quit("create socket error\n",stdout);
	}

	bzero(&servaddr, sizeof(servaddr));
	servaddr.sin_family = AF_INET;
	servaddr.sin_addr.s_addr = htonl(INADDR_ANY);
	servaddr.sin_port = htons(12000);

	if( -1 == bind(listenfd, (struct sockaddr *) &servaddr, sizeof(servaddr)) ) {
		error_quit("bind error\n",stdout);
	}

	if( -1 == listen(listenfd, SOMAXCONN) ) {
		error_quit("listen error\n",stdout);
	}

	for ( ; ; ) {
		connfd = accept(listenfd, (struct sockaddr *) NULL, NULL);
		
		if ( (cid = fork()) == 0) { /* child process */
			close(listenfd);    /* close listening socket */
			/* do not call recv from socket, just fill in buff */
			strcpy(buff, "write some data to socket buff");	
			while (1) {
				if(-1 == writen(connfd, buff, sizeof(buff)) )
					error_quit("write to socket error, exit",stdout);
			}
			printf("child %d exits\n", getpid());
			exit (0);
		}
		else if(cid < 0){
			printf("warning failed to fork new child\n");
		}
		else {
			n++;
			printf("new connection established, %d\n", n);
			fflush(stdout);
		}
		close(connfd);          /* parent closes connected socket */
	}
}
